/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */
package org.jdtaus.core.container.it;

import org.jdtaus.core.container.ContainerFactory;
import org.jdtaus.core.container.ContainerInitializer;
import org.jdtaus.core.container.ContextFactory;
import org.jdtaus.core.container.ContextInitializer;
import org.jdtaus.core.container.Dependency;
import org.jdtaus.core.container.Implementation;
import org.jdtaus.core.container.ModelFactory;
import org.jdtaus.core.container.Properties;
import org.jdtaus.core.container.Property;
import org.jdtaus.core.logging.spi.Logger;

/**
 * Implementation used for testing the {@code Container} runtime.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: TestImplementation.java 4610 2008-03-10 02:48:18Z schulte2005 $
 */
public class TestImplementation
    implements TestSpecification, ContainerInitializer
{
    //--Implementation----------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausImplementation
    // This section is managed by jdtaus-container-mojo.

    /** Meta-data describing the implementation. */
    private static final Implementation META =
        ModelFactory.getModel().getModules().
        getImplementation(TestImplementation.class.getName());
// </editor-fold>//GEN-END:jdtausImplementation

    //----------------------------------------------------------Implementation--
    //--Constructors------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausConstructors
    // This section is managed by jdtaus-container-mojo.

    /**
     * <code>TestImplementation</code> implementation constructor.
     *
     * @param meta Implementation meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    protected TestImplementation(final Implementation meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }
    /**
     * <code>TestImplementation</code> dependency constructor.
     *
     * @param meta dependency meta-data.
     *
     * @throws NullPointerException if <code>meta</code> is <code>null</code>.
     */
    protected TestImplementation(final Dependency meta)
    {
        super();
        if(meta == null)
        {
            throw new NullPointerException("meta");
        }
        this.initializeProperties(meta.getProperties());
    }

    /**
     * Initializes the properties of the instance.
     *
     * @param meta the property values to initialize the instance with.
     *
     * @throws NullPointerException if {@code meta} is {@code null}.
     */
    protected void initializeProperties(final Properties meta)
    {
        Property p;

        if(meta == null)
        {
            throw new NullPointerException("meta");
        }

        p = meta.getProperty("stringObject");
        this.pStringObject = (java.lang.String) p.getValue();


        p = meta.getProperty("shortObject");
        this.pShortObject = (java.lang.Short) p.getValue();


        p = meta.getProperty("longObject");
        this.pLongObject = (java.lang.Long) p.getValue();


        p = meta.getProperty("integerObject");
        this.pIntegerObject = (java.lang.Integer) p.getValue();


        p = meta.getProperty("floatObject");
        this.pFloatObject = (java.lang.Float) p.getValue();


        p = meta.getProperty("doubleObject");
        this.pDoubleObject = (java.lang.Double) p.getValue();


        p = meta.getProperty("characterObject");
        this.pCharacterObject = (java.lang.Character) p.getValue();


        p = meta.getProperty("byteObject");
        this.pByteObject = (java.lang.Byte) p.getValue();


        p = meta.getProperty("booleanObject");
        this.pBooleanObject = (java.lang.Boolean) p.getValue();


        p = meta.getProperty("short");
        this.pShort = ((java.lang.Short) p.getValue()).shortValue();


        p = meta.getProperty("long");
        this.pLong = ((java.lang.Long) p.getValue()).longValue();


        p = meta.getProperty("int");
        this.pInt = ((java.lang.Integer) p.getValue()).intValue();


        p = meta.getProperty("float");
        this.pFloat = ((java.lang.Float) p.getValue()).floatValue();


        p = meta.getProperty("double");
        this.pDouble = ((java.lang.Double) p.getValue()).doubleValue();


        p = meta.getProperty("char");
        this.pChar = ((java.lang.Character) p.getValue()).charValue();


        p = meta.getProperty("byte");
        this.pByte = ((java.lang.Byte) p.getValue()).byteValue();


        p = meta.getProperty("boolean");
        this.pBoolean = ((java.lang.Boolean) p.getValue()).booleanValue();

    }
// </editor-fold>//GEN-END:jdtausConstructors

    //------------------------------------------------------------Constructors--
    //--ContainerInitializer----------------------------------------------------

    /** Flag indicating that the {@link #initialize()} method got called. */
    private boolean initialized;

    public void initialize()
    {
        this.initialized = true;
    }

    //----------------------------------------------------ContainerInitializer--
    //--Dependencies------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausDependencies
    // This section is managed by jdtaus-container-mojo.

    /** Configured <code>Logger</code> implementation. */
    private transient Logger dLogger;

    /**
     * Gets the configured <code>Logger</code> implementation.
     *
     * @return the configured <code>Logger</code> implementation.
     */
    private Logger getLogger()
    {
        Logger ret = null;
        if(this.dLogger != null)
        {
            ret = this.dLogger;
        }
        else
        {
            ret = (Logger) ContainerFactory.getContainer().
                getDependency(TestImplementation.class,
                "Logger");

            if(ModelFactory.getModel().getModules().
                getImplementation(TestImplementation.class.getName()).
                getDependencies().getDependency("Logger").
                isBound())
            {
                this.dLogger = ret;
            }
        }

        if(ret instanceof ContextInitializer && !((ContextInitializer) ret).
            isInitialized(ContextFactory.getContext()))
        {
            ((ContextInitializer) ret).initialize(ContextFactory.getContext());
        }

        return ret;
    }
// </editor-fold>//GEN-END:jdtausDependencies

    //------------------------------------------------------------Dependencies--
    //--Properties--------------------------------------------------------------

// <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:jdtausProperties
    // This section is managed by jdtaus-container-mojo.

    /**
     * Property {@code stringObject}.
     * @serial
     */
    private java.lang.String pStringObject;

    /**
     * Gets the value of property <code>stringObject</code>.
     *
     * @return the value of property <code>stringObject</code>.
     */
    public java.lang.String getStringObject()
    {
        return this.pStringObject;
    }

    /**
     * Property {@code shortObject}.
     * @serial
     */
    private java.lang.Short pShortObject;

    /**
     * Gets the value of property <code>shortObject</code>.
     *
     * @return the value of property <code>shortObject</code>.
     */
    public java.lang.Short getShortObject()
    {
        return this.pShortObject;
    }

    /**
     * Property {@code longObject}.
     * @serial
     */
    private java.lang.Long pLongObject;

    /**
     * Gets the value of property <code>longObject</code>.
     *
     * @return the value of property <code>longObject</code>.
     */
    public java.lang.Long getLongObject()
    {
        return this.pLongObject;
    }

    /**
     * Property {@code integerObject}.
     * @serial
     */
    private java.lang.Integer pIntegerObject;

    /**
     * Gets the value of property <code>integerObject</code>.
     *
     * @return the value of property <code>integerObject</code>.
     */
    public java.lang.Integer getIntegerObject()
    {
        return this.pIntegerObject;
    }

    /**
     * Property {@code floatObject}.
     * @serial
     */
    private java.lang.Float pFloatObject;

    /**
     * Gets the value of property <code>floatObject</code>.
     *
     * @return the value of property <code>floatObject</code>.
     */
    public java.lang.Float getFloatObject()
    {
        return this.pFloatObject;
    }

    /**
     * Property {@code doubleObject}.
     * @serial
     */
    private java.lang.Double pDoubleObject;

    /**
     * Gets the value of property <code>doubleObject</code>.
     *
     * @return the value of property <code>doubleObject</code>.
     */
    public java.lang.Double getDoubleObject()
    {
        return this.pDoubleObject;
    }

    /**
     * Property {@code characterObject}.
     * @serial
     */
    private java.lang.Character pCharacterObject;

    /**
     * Gets the value of property <code>characterObject</code>.
     *
     * @return the value of property <code>characterObject</code>.
     */
    public java.lang.Character getCharacterObject()
    {
        return this.pCharacterObject;
    }

    /**
     * Property {@code byteObject}.
     * @serial
     */
    private java.lang.Byte pByteObject;

    /**
     * Gets the value of property <code>byteObject</code>.
     *
     * @return the value of property <code>byteObject</code>.
     */
    public java.lang.Byte getByteObject()
    {
        return this.pByteObject;
    }

    /**
     * Property {@code booleanObject}.
     * @serial
     */
    private java.lang.Boolean pBooleanObject;

    /**
     * Gets the value of property <code>booleanObject</code>.
     *
     * @return the value of property <code>booleanObject</code>.
     */
    public java.lang.Boolean isBooleanObject()
    {
        return this.pBooleanObject;
    }

    /**
     * Property {@code short}.
     * @serial
     */
    private short pShort;

    /**
     * Gets the value of property <code>short</code>.
     *
     * @return the value of property <code>short</code>.
     */
    public short getShort()
    {
        return this.pShort;
    }

    /**
     * Property {@code long}.
     * @serial
     */
    private long pLong;

    /**
     * Gets the value of property <code>long</code>.
     *
     * @return the value of property <code>long</code>.
     */
    public long getLong()
    {
        return this.pLong;
    }

    /**
     * Property {@code int}.
     * @serial
     */
    private int pInt;

    /**
     * Gets the value of property <code>int</code>.
     *
     * @return the value of property <code>int</code>.
     */
    public int getInt()
    {
        return this.pInt;
    }

    /**
     * Property {@code float}.
     * @serial
     */
    private float pFloat;

    /**
     * Gets the value of property <code>float</code>.
     *
     * @return the value of property <code>float</code>.
     */
    public float getFloat()
    {
        return this.pFloat;
    }

    /**
     * Property {@code double}.
     * @serial
     */
    private double pDouble;

    /**
     * Gets the value of property <code>double</code>.
     *
     * @return the value of property <code>double</code>.
     */
    public double getDouble()
    {
        return this.pDouble;
    }

    /**
     * Property {@code char}.
     * @serial
     */
    private char pChar;

    /**
     * Gets the value of property <code>char</code>.
     *
     * @return the value of property <code>char</code>.
     */
    public char getChar()
    {
        return this.pChar;
    }

    /**
     * Property {@code byte}.
     * @serial
     */
    private byte pByte;

    /**
     * Gets the value of property <code>byte</code>.
     *
     * @return the value of property <code>byte</code>.
     */
    public byte getByte()
    {
        return this.pByte;
    }

    /**
     * Property {@code boolean}.
     * @serial
     */
    private boolean pBoolean;

    /**
     * Gets the value of property <code>boolean</code>.
     *
     * @return the value of property <code>boolean</code>.
     */
    public boolean isBoolean()
    {
        return this.pBoolean;
    }

// </editor-fold>//GEN-END:jdtausProperties

    //--------------------------------------------------------------Properties--
    //--TestSpecification-------------------------------------------------------

    public boolean isInitialized()
    {
        return this.initialized;
    }

    //-------------------------------------------------------TestSpecification--
}
